@@ -993,13 +993,16 @@ class account():
             #msgDate = date.fromtimestamp(secsSinceEpoc)
         except ValueError:
             try:
-                msgDate = datetime.datetime.strptime(timestr, "%a, %d %b %Y %H:%M:%S +0000")
+                print "trying timestamp format Mon, Jan 01 2010 00:00:00 +0000"
+                msgDate = datetime.datetime.strptime(strippedDate, "%a, %d %b %Y %H:%M:%S +0000")
             except ValueError:
                 try:
-                    msgDate = datetime.datetime.strptime(timestr, "%a %b %d %H:%M:%S +0000 %Y")
+                    print "trying third format"
+                    msgDate = datetime.datetime.strptime(strippedDate, "%a %b %d %H:%M:%S +0000 %Y")
                 except ValueError, e:
                     print e
-                    return timestr
+                    print "returning datestamp for now"
+                    return datetime.datetime.today()
 
         timestamp = msgDate.time()
         print timestamp.tzinfo
@@ -1016,7 +1019,7 @@ class account():
             td = datetime.timedelta(hours=0 - hoursOffset, seconds=tz)
         else:
             td = datetime.timedelta(hours=hoursOffset, seconds=tz)
-        print td
+        
         timestamp = msgDate - td
         mytz = "%+4.4d" % (tz / -(60 * 60) * 100) # time.timezone counts westwards!
         print timestamp
