@@ -155,7 +155,7 @@ class Witter():
 
         #pass the witter ui a reference to this object for callbacks
         self.ui = ui.WitterUI(self)
-        self.ui.setActiveListStore(self.activeAccount.getTimeline())
+        self.ui.setActiveListStore(self.activeAccount.getTimeline(),4)
         self.ui.theme = self.theme
         self.ui.select_ui_theme(self.theme)
         self.gettingTweets = False
